@@ -1,6 +1,6 @@
 __version__ = "0.1.0"
 
-from .gql import GQLException
+from .errors import GQLException
 from .gql_input import GQLInput
 from .node import Node, Cache, CacheManager
 from .resolver import Resolver
