@@ -180,7 +180,11 @@ class Node(BaseModel):
     def __hash__(self) -> int:
         return hash(f"{self.__class__.__name__}{self._uid}")
 
-    def to_ref(self) -> GQL.ref_model:
+    def to_ref(self, field_names: T.List[str] = None) -> GQL.ref_model:
+        if field_names:
+            return self.GQL.ref_model.parse_obj(
+                {field_name: getattr(self, field_name) for field_name in field_names}
+            )
         return self.GQL.ref_model.parse_obj(self.dict())
 
     @property
